import lodash from 'lodash'
import { interact, replaceApiParams } from '../../utils'
import apis from '../../config/api'

export default {
  namespaced: true,
  state: {
    words: {},
    detail: {
      weight: 0.85,
      status: 1,
    }
  },
  mutations: {
    updateList (state, payload) {
      state.words = payload || {}
    },
    updateDetail (state, payload) {
      state.detail = payload || {}
    }
  },
  actions: {
    setDetailNull ({ commit }) {
      commit('updateDetail', { weight: 0.85, status: 1 })
    },
    getWordsList ({ commit }, payload) {
      return new Promise((resolve, reject) => {
        const api = lodash.get(apis, 'words.list')
        interact(api, payload).then((data) => {
          resolve(data)
          commit('updateList', data)
        }).catch(() => {
          reject()
        })
      })
    },
    getDetail ({ commit }, payload) {
      const api = replaceApiParams(lodash.get(apis, 'words.detail'), payload)
      interact(api).then((data) => {
        commit('updateDetail', data)
      })
    },
    addWords ( _, payload) {
      const { onSuccess } = payload
      const api = lodash.get(apis, 'words.add')
      interact(api, payload.detail).then((data) => {
        onSuccess(data)
      })
    },
    editWords ( _, payload) {
      const { onSuccess } = payload
      const api = lodash.get(apis, 'words.edit')
      interact(api, payload.detail).then((data) => {
        onSuccess(data)
      })
    },
    deleteWords ( _, payload) {
      return new Promise((resolve, reject) => {
        const api = replaceApiParams(lodash.get(apis, 'words.delete'), payload)
        interact(api).then((data) => {
          resolve(data)
        }).catch(() => {
          reject()
        })
      })
    }
  }
}
